@@ -13,11 +13,13 @@ OC.L10N.register(
     "There was an error fetching the member list" : "擷取成員清單出錯",
     "Please select a team" : "請選取團隊",
     "Loading team…" : "正在加載團隊 …",
+    "Loading contacts …" : "正在加載聯絡人 …",
     "There are no contacts yet" : "目前沒有聯絡人",
     "Create contact" : "建立聯絡人",
     "There are no contacts in this group" : "群組中沒有聯絡人",
     "Create contacts" : "建立聯絡人",
     "Add contacts" : "新增聯絡人",
+    "Loading …" : "正在加載 …",
     "Manage team" : "管理團隊",
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
@@ -58,7 +60,7 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "取消分享 {addressbook}？",
     "Deletion of address book was not successful." : "刪除通訊錄失敗。",
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "{addressbookname} (Hidden)" : "{addressbookname}（隱藏）",
     "Download" : "下載",
     "Show" : "顯示",
     "Unshare from me" : "取消與我分享",
@@ -90,6 +92,7 @@ OC.L10N.register(
     "An error happened during the config change" : "配置更改期間發生錯誤",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
+    "Unique password …" : "獨一無二的密碼 ...",
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
     "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
@@ -161,6 +164,7 @@ OC.L10N.register(
     "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
     "Please select two editable contacts to merge" : "請選擇兩個可編輯的聯絡人進行合併",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
+    "Search contacts …" : "搜尋聯絡人 …",
     "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group]",
     "Add members to {group}" : "添加成員至 {group}",
@@ -194,9 +198,13 @@ OC.L10N.register(
     "Unable to get the results" : "無法得到結果",
     "Some members could not be added" : "部分成員無法添加",
     "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
+    "Loading members list …" : "正在加載成員清單 …",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取會員清單",
+    "Add to {team}" : "添加至 {team}",
+    "Invite members to {team}" : "邀請成員加入 {team}",
     "Pending" : "待定的",
+    "Select chart …" : "選擇圖表 ...",
     "Chart" : "圖表",
     "Select Date" : "選擇日期",
     "Select type" : "選擇類型",
@@ -327,6 +335,7 @@ OC.L10N.register(
     "Unable to delete contact" : "無法刪除聯絡人",
     "Loading contacts …" : "正在載入通訊錄 …",
     "Loading …" : "正在載入 …",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Unique password …" : "獨一無二的密碼 ...",
     "Search contacts …" : "搜尋聯絡人…",
     "Invite members to team" : "邀請成員加入團隊",
